package be.iminds.ilabt.jfed.experimenter_gui.editor;

import javax.annotation.Nonnull;
import java.util.*;

public class ToolBoxFilterBuilder {
    @Nonnull private Set<String> testbedIds;
    @Nonnull private Set<String> organisationIds;
    @Nonnull private Set<String> categoryNames;
    @Nonnull private Set<String> federationIds;
    private boolean orIntra;

    public ToolBoxFilterBuilder() {
        testbedIds = new TreeSet<>();
        organisationIds = new TreeSet<>();
        categoryNames = new TreeSet<>();
        federationIds = new TreeSet<>();
        orIntra = false;
    }
    public ToolBoxFilterBuilder(ToolBoxFilter orig) {
        testbedIds = new TreeSet<>(orig.getTestbedIds());
        organisationIds = new TreeSet<>(orig.getOrganisationIds());
        categoryNames = new TreeSet<>(orig.getCategoryNames());
        federationIds = new TreeSet<>(orig.getFederationIds());
        orIntra = orig.isOrIntra();
    }

    public ToolBoxFilterBuilder(ToolBoxFilterBuilder orig) {
        testbedIds = new TreeSet<>(orig.testbedIds);
        organisationIds = new TreeSet<>(orig.organisationIds);
        categoryNames = new TreeSet<>(orig.categoryNames);
        federationIds = new TreeSet<>(orig.federationIds);
        orIntra = orig.orIntra;
    }

    public ToolBoxFilterBuilder setTestbedIds(Collection<String> testbedIds) {
        this.testbedIds = new TreeSet<>(testbedIds);
        return this;
    }

    public ToolBoxFilterBuilder setOrganisationIds(Collection<String> organisationIds) {
        this.organisationIds = new TreeSet<>(organisationIds);
        return this;
    }

    public ToolBoxFilterBuilder setCategoryNames(Collection<String> categoryNames) {
        this.categoryNames = new TreeSet<>(categoryNames);
        return this;
    }

    public ToolBoxFilterBuilder setFederationIds(Collection<String> federationIds) {
        this.federationIds = new TreeSet<>(federationIds);
        return this;
    }

    public ToolBoxFilterBuilder setOrIntra(boolean orIntra) {
        this.orIntra = orIntra;
        return this;
    }

    public ToolBoxFilterBuilder addTestbedId(String... ids) {
        this.testbedIds.addAll(Arrays.asList(ids));
        return this;
    }

    public ToolBoxFilterBuilder addOrganisationId(String... ids) {
        this.organisationIds.addAll(Arrays.asList(ids));
        return this;
    }

    public ToolBoxFilterBuilder addCategoryName(String... names) {
        this.categoryNames.addAll(Arrays.asList(names));
        return this;
    }

    public ToolBoxFilterBuilder addFederationId(String... ids) {
        this.federationIds.addAll(Arrays.asList(ids));
        return this;
    }

    public ToolBoxFilterBuilder removeTestbedId(String id) {
        this.testbedIds.remove(id);
        return this;
    }

    public ToolBoxFilterBuilder removeOrganisationId(String id) {
        this.organisationIds.remove(id);
        return this;
    }

    public ToolBoxFilterBuilder removeCategoryName(String name) {
        this.categoryNames.remove(name);
        return this;
    }

    public ToolBoxFilterBuilder removeFederationId(String id) {
        this.federationIds.remove(id);
        return this;
    }


    public ToolBoxFilter create() {
        return new ToolBoxFilter(testbedIds, organisationIds, categoryNames, federationIds, orIntra);
    }
}